import vlc, pafy
import time
import threading
import random

class AudioPlayer:
  def __init__(self, url: str):
    self.mediaResource = pafy.new(url.strip())
    self.player = vlc.MediaPlayer(self.mediaResource.getbestaudio().url)
    self.eventManager = self.player.event_manager()
    self.audioFinished = threading.Condition()
    self.finished = False

    self.eventManager.event_attach(vlc.EventType.MediaPlayerEndReached, self.finish)
    self.eventManager.event_attach(vlc.EventType.MediaPlayerEncounteredError, self.finish)

  def play(self):
    self.player.play()
    print('# Now playing: ' + self.mediaResource.title)

  def finish(self, event):
    self.audioFinished.acquire()
    self.finished = True
    self.audioFinished.notifyAll()
    self.audioFinished.release()

  def waitUntilFinished(self):
    self.audioFinished.acquire()
    self.audioFinished.wait_for(lambda: self.finished)
    self.audioFinished.release()

def main():
  with open('playlist.txt', 'r') as playListFile:
    urls = playListFile.readlines()
    while True:
      idx = random.randint(0, len(urls) - 1)
      player = AudioPlayer(urls[idx])
      player.play()
      player.waitUntilFinished()




import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='termplayer',
    version="0.0.1",
    author="NeoClear",
    author_email="neoclear@outlook.com",
    description="A python program to help you play youtube playlists on your terminal",
    long_description=long_description,
    long_description_content_type="text/markdown",
    # url="https://github.com/pypa/sampleproject",
    # project_urls={
    #     "Bug Tracker": "https://github.com/pypa/sampleproject/issues",
    # },
    # classifiers=[
    #     "Programming Language :: Python :: 3",
    #     "License :: OSI Approved :: MIT License",
    #     "Operating System :: OS Independent",
    # ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    install_required=[
      'git+https://github.com/Cupcakus/pafy',
      'youtube-dl==2021.12.17',
      'python-vlc==3.0.12118'
    ]
)
